/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.clustering.web.sso;

import java.util.ServiceConfigurationError;
import java.util.ServiceLoader;

import org.jboss.msc.service.Service;
import org.jboss.msc.service.StartContext;
import org.jboss.msc.service.StartException;
import org.jboss.msc.service.StopContext;

/**
 * @author Paul Ferraro
 */
public class SSOClusterManagerService implements Service<SSOClusterManager> {

    private final SSOClusterManager manager;

    public SSOClusterManagerService() {
        this(load());
    }

    public SSOClusterManagerService(SSOClusterManager manager) {
        this.manager = manager;
    }

    private static SSOClusterManager load() {
        for (SSOClusterManager manager: ServiceLoader.load(SSOClusterManager.class, SSOClusterManager.class.getClassLoader())) {
            return manager;
        }
        throw new ServiceConfigurationError(SSOClusterManager.class.getName());
    }

    @Override
    public SSOClusterManager getValue() {
        return this.manager;
    }

    @Override
    public void start(StartContext context) throws StartException {
        try {
            this.manager.start();
        } catch (Exception e) {
            throw new StartException(e);
        }
    }

    @Override
    public void stop(StopContext context) {
        try {
            this.manager.stop();
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }
}
